Computes a convex shrinkage covariance estimator of the form $$\Sigma_{\lambda} = (1 - \lambda)S + \lambda T,$$ where \(S\) is the sample covariance matrix and \(T\) is a scaled identity target.
Computes a convex shrinkage covariance estimator of the form $$\Sigma_{\lambda} = (1 - \lambda)S + \lambda T,$$ where \(S\) is the sample covariance matrix and \(T\) is a scaled identity target.